import { presetCommon } from "./common.js";
import { presetEverything } from "./everything.js";
import { presetMinimal } from "./minimal.js";
import * as bingo_stratum754 from "bingo-stratum";
import * as zod625 from "zod";

//#region src/presets/index.d.ts
declare const presets: {
  common: bingo_stratum754.Preset<{
    access: zod625.ZodUnion<[zod625.ZodLiteral<"public">, zod625.ZodLiteral<"restricted">]>;
    author: zod625.ZodOptional<zod625.ZodString>;
    bin: zod625.ZodOptional<zod625.ZodUnion<[zod625.ZodString, zod625.ZodRecord<zod625.ZodString, zod625.ZodString>]>>;
    contributors: zod625.ZodOptional<zod625.ZodArray<zod625.ZodObject<{
      avatar_url: zod625.ZodString;
      contributions: zod625.ZodArray<zod625.ZodString, "many">;
      login: zod625.ZodString;
      name: zod625.ZodString;
      profile: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod625.ZodDefault<zod625.ZodString>;
    directory: zod625.ZodString;
    documentation: zod625.ZodObject<{
      development: zod625.ZodOptional<zod625.ZodString>;
      readme: zod625.ZodObject<{
        additional: zod625.ZodOptional<zod625.ZodString>;
        explainer: zod625.ZodOptional<zod625.ZodString>;
        footnotes: zod625.ZodOptional<zod625.ZodString>;
        usage: zod625.ZodOptional<zod625.ZodString>;
      }, "strip", zod625.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod625.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod625.ZodEffects<zod625.ZodUnion<[zod625.ZodString, zod625.ZodObject<{
      github: zod625.ZodString;
      npm: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod625.ZodOptional<zod625.ZodString>;
    existingLabels: zod625.ZodOptional<zod625.ZodArray<zod625.ZodObject<{
      color: zod625.ZodString;
      description: zod625.ZodString;
      name: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod625.ZodOptional<zod625.ZodString>;
    guide: zod625.ZodOptional<zod625.ZodObject<{
      href: zod625.ZodString;
      title: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod625.ZodOptional<zod625.ZodArray<zod625.ZodString, "many">>;
    logo: zod625.ZodOptional<zod625.ZodObject<{
      alt: zod625.ZodString;
      height: zod625.ZodOptional<zod625.ZodNumber>;
      src: zod625.ZodString;
      width: zod625.ZodOptional<zod625.ZodNumber>;
    }, "strip", zod625.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod625.ZodObject<{
      minimum: zod625.ZodString;
      pinned: zod625.ZodOptional<zod625.ZodString>;
    }, "strip", zod625.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod625.ZodString;
    packageData: zod625.ZodOptional<zod625.ZodObject<{
      dependencies: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodString>>;
      devDependencies: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodString>>;
      peerDependencies: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodString>>;
      peerDependenciesMeta: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodUnknown>>;
      scripts: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodOptional<zod625.ZodString>>>;
    }, "strip", zod625.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod625.ZodOptional<zod625.ZodString>;
    repository: zod625.ZodString;
    rulesetId: zod625.ZodOptional<zod625.ZodString>;
    title: zod625.ZodString;
    type: zod625.ZodOptional<zod625.ZodUnion<[zod625.ZodLiteral<"commonjs">, zod625.ZodLiteral<"module">]>>;
    version: zod625.ZodOptional<zod625.ZodString>;
    words: zod625.ZodOptional<zod625.ZodArray<zod625.ZodString, "many">>;
    workflowsVersions: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodRecord<zod625.ZodString, zod625.ZodObject<{
      hash: zod625.ZodOptional<zod625.ZodString>;
      pinned: zod625.ZodOptional<zod625.ZodBoolean>;
    }, "strip", zod625.ZodTypeAny, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }>>>>;
  }>;
  everything: bingo_stratum754.Preset<{
    access: zod625.ZodUnion<[zod625.ZodLiteral<"public">, zod625.ZodLiteral<"restricted">]>;
    author: zod625.ZodOptional<zod625.ZodString>;
    bin: zod625.ZodOptional<zod625.ZodUnion<[zod625.ZodString, zod625.ZodRecord<zod625.ZodString, zod625.ZodString>]>>;
    contributors: zod625.ZodOptional<zod625.ZodArray<zod625.ZodObject<{
      avatar_url: zod625.ZodString;
      contributions: zod625.ZodArray<zod625.ZodString, "many">;
      login: zod625.ZodString;
      name: zod625.ZodString;
      profile: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod625.ZodDefault<zod625.ZodString>;
    directory: zod625.ZodString;
    documentation: zod625.ZodObject<{
      development: zod625.ZodOptional<zod625.ZodString>;
      readme: zod625.ZodObject<{
        additional: zod625.ZodOptional<zod625.ZodString>;
        explainer: zod625.ZodOptional<zod625.ZodString>;
        footnotes: zod625.ZodOptional<zod625.ZodString>;
        usage: zod625.ZodOptional<zod625.ZodString>;
      }, "strip", zod625.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod625.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod625.ZodEffects<zod625.ZodUnion<[zod625.ZodString, zod625.ZodObject<{
      github: zod625.ZodString;
      npm: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod625.ZodOptional<zod625.ZodString>;
    existingLabels: zod625.ZodOptional<zod625.ZodArray<zod625.ZodObject<{
      color: zod625.ZodString;
      description: zod625.ZodString;
      name: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod625.ZodOptional<zod625.ZodString>;
    guide: zod625.ZodOptional<zod625.ZodObject<{
      href: zod625.ZodString;
      title: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod625.ZodOptional<zod625.ZodArray<zod625.ZodString, "many">>;
    logo: zod625.ZodOptional<zod625.ZodObject<{
      alt: zod625.ZodString;
      height: zod625.ZodOptional<zod625.ZodNumber>;
      src: zod625.ZodString;
      width: zod625.ZodOptional<zod625.ZodNumber>;
    }, "strip", zod625.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod625.ZodObject<{
      minimum: zod625.ZodString;
      pinned: zod625.ZodOptional<zod625.ZodString>;
    }, "strip", zod625.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod625.ZodString;
    packageData: zod625.ZodOptional<zod625.ZodObject<{
      dependencies: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodString>>;
      devDependencies: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodString>>;
      peerDependencies: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodString>>;
      peerDependenciesMeta: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodUnknown>>;
      scripts: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodOptional<zod625.ZodString>>>;
    }, "strip", zod625.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod625.ZodOptional<zod625.ZodString>;
    repository: zod625.ZodString;
    rulesetId: zod625.ZodOptional<zod625.ZodString>;
    title: zod625.ZodString;
    type: zod625.ZodOptional<zod625.ZodUnion<[zod625.ZodLiteral<"commonjs">, zod625.ZodLiteral<"module">]>>;
    version: zod625.ZodOptional<zod625.ZodString>;
    words: zod625.ZodOptional<zod625.ZodArray<zod625.ZodString, "many">>;
    workflowsVersions: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodRecord<zod625.ZodString, zod625.ZodObject<{
      hash: zod625.ZodOptional<zod625.ZodString>;
      pinned: zod625.ZodOptional<zod625.ZodBoolean>;
    }, "strip", zod625.ZodTypeAny, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }>>>>;
  }>;
  minimal: bingo_stratum754.Preset<{
    access: zod625.ZodUnion<[zod625.ZodLiteral<"public">, zod625.ZodLiteral<"restricted">]>;
    author: zod625.ZodOptional<zod625.ZodString>;
    bin: zod625.ZodOptional<zod625.ZodUnion<[zod625.ZodString, zod625.ZodRecord<zod625.ZodString, zod625.ZodString>]>>;
    contributors: zod625.ZodOptional<zod625.ZodArray<zod625.ZodObject<{
      avatar_url: zod625.ZodString;
      contributions: zod625.ZodArray<zod625.ZodString, "many">;
      login: zod625.ZodString;
      name: zod625.ZodString;
      profile: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod625.ZodDefault<zod625.ZodString>;
    directory: zod625.ZodString;
    documentation: zod625.ZodObject<{
      development: zod625.ZodOptional<zod625.ZodString>;
      readme: zod625.ZodObject<{
        additional: zod625.ZodOptional<zod625.ZodString>;
        explainer: zod625.ZodOptional<zod625.ZodString>;
        footnotes: zod625.ZodOptional<zod625.ZodString>;
        usage: zod625.ZodOptional<zod625.ZodString>;
      }, "strip", zod625.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod625.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod625.ZodEffects<zod625.ZodUnion<[zod625.ZodString, zod625.ZodObject<{
      github: zod625.ZodString;
      npm: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod625.ZodOptional<zod625.ZodString>;
    existingLabels: zod625.ZodOptional<zod625.ZodArray<zod625.ZodObject<{
      color: zod625.ZodString;
      description: zod625.ZodString;
      name: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod625.ZodOptional<zod625.ZodString>;
    guide: zod625.ZodOptional<zod625.ZodObject<{
      href: zod625.ZodString;
      title: zod625.ZodString;
    }, "strip", zod625.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod625.ZodOptional<zod625.ZodArray<zod625.ZodString, "many">>;
    logo: zod625.ZodOptional<zod625.ZodObject<{
      alt: zod625.ZodString;
      height: zod625.ZodOptional<zod625.ZodNumber>;
      src: zod625.ZodString;
      width: zod625.ZodOptional<zod625.ZodNumber>;
    }, "strip", zod625.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod625.ZodObject<{
      minimum: zod625.ZodString;
      pinned: zod625.ZodOptional<zod625.ZodString>;
    }, "strip", zod625.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod625.ZodString;
    packageData: zod625.ZodOptional<zod625.ZodObject<{
      dependencies: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodString>>;
      devDependencies: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodString>>;
      peerDependencies: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodString>>;
      peerDependenciesMeta: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodUnknown>>;
      scripts: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodOptional<zod625.ZodString>>>;
    }, "strip", zod625.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod625.ZodOptional<zod625.ZodString>;
    repository: zod625.ZodString;
    rulesetId: zod625.ZodOptional<zod625.ZodString>;
    title: zod625.ZodString;
    type: zod625.ZodOptional<zod625.ZodUnion<[zod625.ZodLiteral<"commonjs">, zod625.ZodLiteral<"module">]>>;
    version: zod625.ZodOptional<zod625.ZodString>;
    words: zod625.ZodOptional<zod625.ZodArray<zod625.ZodString, "many">>;
    workflowsVersions: zod625.ZodOptional<zod625.ZodRecord<zod625.ZodString, zod625.ZodRecord<zod625.ZodString, zod625.ZodObject<{
      hash: zod625.ZodOptional<zod625.ZodString>;
      pinned: zod625.ZodOptional<zod625.ZodBoolean>;
    }, "strip", zod625.ZodTypeAny, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }>>>>;
  }>;
};
//#endregion
export { presetCommon, presetEverything, presetMinimal, presets };
//# sourceMappingURL=index.d.ts.map